@@ -3,10 +3,8 @@ package archiver
 import (
 	"context"
 	"fmt"
-	"io/ioutil"
 	"os"
 	"path/filepath"
-	"runtime"
 	"testing"
 	"time"
 
@@ -63,15 +61,11 @@ func createFilesAt(t testing.TB, targetdir string, files map[string]interface{})
 
 		switch it := item.(type) {
 		case TestFile:
-			err := ioutil.WriteFile(target, []byte(it.Content), 0600)
+			err := os.WriteFile(target, []byte(it.Content), 0600)
 			if err != nil {
 				t.Fatal(err)
 			}
 		case TestSymlink:
-			// ignore symlinks on windows
-			if runtime.GOOS == "windows" {
-				continue
-			}
 			err := fs.Symlink(filepath.FromSlash(it.Target), target)
 			if err != nil {
 				t.Fatal(err)
@@ -93,7 +87,7 @@ func TestTestCreateFiles(t *testing.T) {
 				},
 				"sub": TestDir{
 					"subsub": TestDir{
-						"link": TestSymlink{Target: "x/y/z"},
+						"link": TestSymlink{Target: filepath.Clean("x/y/z")},
 					},
 				},
 			},
@@ -101,14 +95,13 @@ func TestTestCreateFiles(t *testing.T) {
 				"foo":             TestFile{Content: "foo"},
 				"subdir":          TestDir{},
 				"subdir/subfile":  TestFile{Content: "bar"},
-				"sub/subsub/link": TestSymlink{Target: "x/y/z"},
+				"sub/subsub/link": TestSymlink{Target: filepath.Clean("x/y/z")},
 			},
 		},
 	}
 
 	for i, test := range tests {
-		tempdir, cleanup := restictest.TempDir(t)
-		defer cleanup()
+		tempdir := restictest.TempDir(t)
 
 		t.Run("", func(t *testing.T) {
 			tempdir := filepath.Join(tempdir, fmt.Sprintf("test-%d", i))
@@ -120,13 +113,6 @@ func TestTestCreateFiles(t *testing.T) {
 			TestCreateFiles(t, tempdir, test.dir)
 
 			for name, item := range test.files {
-				// don't check symlinks on windows
-				if runtime.GOOS == "windows" {
-					if _, ok := item.(TestSymlink); ok {
-						continue
-					}
-				}
-
 				targetPath := filepath.Join(tempdir, filepath.FromSlash(name))
 				fi, err := fs.Lstat(targetPath)
 				if err != nil {
@@ -141,7 +127,7 @@ func TestTestCreateFiles(t *testing.T) {
 						continue
 					}
 
-					content, err := ioutil.ReadFile(targetPath)
+					content, err := os.ReadFile(targetPath)
 					if err != nil {
 						t.Error(err)
 						continue
@@ -205,8 +191,7 @@ func TestTestWalkFiles(t *testing.T) {
 
 	for _, test := range tests {
 		t.Run("", func(t *testing.T) {
-			tempdir, cleanup := restictest.TempDir(t)
-			defer cleanup()
+			tempdir := restictest.TempDir(t)
 
 			got := make(map[string]string)
 
@@ -217,7 +202,7 @@ func TestTestWalkFiles(t *testing.T) {
 					return err
 				}
 
-				got[p] = fmt.Sprintf("%v", item)
+				got[p] = fmt.Sprint(item)
 				return nil
 			})
 
@@ -233,13 +218,12 @@ func TestTestEnsureFiles(t *testing.T) {
 		expectFailure bool
 		files         map[string]interface{}
 		want          TestDir
-		unixOnly      bool
 	}{
 		{
 			files: map[string]interface{}{
 				"foo":            TestFile{Content: "foo"},
 				"subdir/subfile": TestFile{Content: "bar"},
-				"x/y/link":       TestSymlink{Target: "../../foo"},
+				"x/y/link":       TestSymlink{Target: filepath.Clean("../../foo")},
 			},
 			want: TestDir{
 				"foo": TestFile{Content: "foo"},
@@ -248,7 +232,7 @@ func TestTestEnsureFiles(t *testing.T) {
 				},
 				"x": TestDir{
 					"y": TestDir{
-						"link": TestSymlink{Target: "../../foo"},
+						"link": TestSymlink{Target: filepath.Clean("../../foo")},
 					},
 				},
 			},
@@ -295,7 +279,6 @@ func TestTestEnsureFiles(t *testing.T) {
 		},
 		{
 			expectFailure: true,
-			unixOnly:      true,
 			files: map[string]interface{}{
 				"foo": TestFile{Content: "foo"},
 			},
@@ -305,7 +288,6 @@ func TestTestEnsureFiles(t *testing.T) {
 		},
 		{
 			expectFailure: true,
-			unixOnly:      true,
 			files: map[string]interface{}{
 				"foo": TestSymlink{Target: "xxx"},
 			},
@@ -339,14 +321,7 @@ func TestTestEnsureFiles(t *testing.T) {
 
 	for _, test := range tests {
 		t.Run("", func(t *testing.T) {
-			if test.unixOnly && runtime.GOOS == "windows" {
-				t.Skip("skip on Windows")
-				return
-			}
-
-			tempdir, cleanup := restictest.TempDir(t)
-			defer cleanup()
-
+			tempdir := restictest.TempDir(t)
 			createFilesAt(t, tempdir, test.files)
 
 			subtestT := testing.TB(t)
@@ -368,7 +343,6 @@ func TestTestEnsureSnapshot(t *testing.T) {
 		expectFailure bool
 		files         map[string]interface{}
 		want          TestDir
-		unixOnly      bool
 	}{
 		{
 			files: map[string]interface{}{
@@ -451,7 +425,6 @@ func TestTestEnsureSnapshot(t *testing.T) {
 		},
 		{
 			expectFailure: true,
-			unixOnly:      true,
 			files: map[string]interface{}{
 				"foo": TestSymlink{Target: filepath.FromSlash("x/y/z")},
 			},
@@ -476,16 +449,10 @@ func TestTestEnsureSnapshot(t *testing.T) {
 
 	for _, test := range tests {
 		t.Run("", func(t *testing.T) {
-			if test.unixOnly && runtime.GOOS == "windows" {
-				t.Skip("skip on Windows")
-				return
-			}
-
 			ctx, cancel := context.WithCancel(context.Background())
 			defer cancel()
 
-			tempdir, cleanup := restictest.TempDir(t)
-			defer cleanup()
+			tempdir := restictest.TempDir(t)
 
 			targetDir := filepath.Join(tempdir, "target")
 			err := fs.Mkdir(targetDir, 0700)
@@ -498,8 +465,7 @@ func TestTestEnsureSnapshot(t *testing.T) {
 			back := restictest.Chdir(t, tempdir)
 			defer back()
 
-			repo, cleanup := repository.TestRepository(t)
-			defer cleanup()
+			repo := repository.TestRepository(t)
 
 			arch := New(repo, fs.Local{}, Options{})
 			opts := SnapshotOptions{
