@@ -50,7 +50,7 @@ func (f *file) Attr(ctx context.Context, a *fuse.Attr) error {
 	a.Inode = f.inode
 	a.Mode = f.node.Mode
 	a.Size = f.node.Size
-	a.Blocks = (f.node.Size / blockSize) + 1
+	a.Blocks = (f.node.Size + blockSize - 1) / blockSize
 	a.BlockSize = blockSize
 	a.Nlink = uint32(f.node.Links)
 
